@@ -253,7 +253,7 @@ def plot_graph(graph, layout_algorithm=kamada_kawai_layout, side=10.00, **kwargs
     """
     components = graph.decompose_into_connected_components()
     if len(components) == 1:
-        return layout_algorithm(graph, **kwargs)
+        return layout_algorithm(graph, side, **kwargs)
     vertices = []
     x_start = 0
     for component in components:
